@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2019, Maximilian Köhl <mkoehl@cs.uni-saarland.de>
+# Copyright (C) 2019-2020, Maximilian Köhl <koehl@cs.uni-saarland.de>
 
 from __future__ import annotations
 
@@ -10,4 +10,4 @@ from .cache import lru_cache
 from .clstools import get_subclasses
 
 
-__all__ = ['checks', 'lru_cache', 'get_subclasses']
+__all__ = ["checks", "lru_cache", "get_subclasses"]
